@@ -30,11 +30,11 @@ Log::AutoDump - Log with automatic dumping of references and objects.
 
 =head1 VERSION
 
-Version 0.09
+Version 0.11
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.11';
 
 $VERSION = eval $VERSION;
 
@@ -146,9 +146,11 @@ sub new
 	              quote_keys => exists $args{ quote_keys } ? $args{ quote_keys } : DEFAULT_QUOTE_KEYS,
 	              filename   => $args{ filename },
 	             _fh         => undef,
+                 autoflush   => exists $args{ autoflush } ? $args{ autoflush } : 1,
 	           };
 
 	$self->{ _fh } = IO::File->new( ">> " . $self->{filename} );
+    $self->{ _fh }->binmode( ":utf8" );
 	$self->{ _fh }->autoflush( 1 );
 
 	bless( $self, $class );
@@ -256,19 +258,26 @@ sub _fh
 	return $self->{ _fh };
 }
 
-=head3 abort
+=head3 autoflush
 
-Close the log filehandle.
+Set the autoflush on the filehandle.
 
- $log->abort;
+ $log->autoflush( 1 );
 
 =cut
 
-sub abort
+sub autoflush
 {
-    my $self = shift;
-    $self->_fh->close;
-    return $self;
+    my ( $self, $autoflush ) = @_;
+
+    if ( defined $autoflush )
+    {
+        $self->{ autoflush } = $autoflush;
+
+        $self->{ _fh }->autoflush( $self->{ autoflush } );
+    }
+
+    return $self->{ autoflush };
 }
 
 =head3 msg
